Summary:	Linux WPA Supplicant (IEEE 802.1X, WPA, WPA2, RSN, IEEE 802.11i)
Name:		wpa_supplicant
Version:	2.6
Release:	6
# wpa_supplicant itself is dual-licensed under GPLv2 and BSD license, but as we
# link against GPL libraries, we must use GPLv2 license
License:	GPLv2+
Group:		Communications
Url:		http://w1.fi/wpa_supplicant/
Source0:	http://w1.fi/releases/wpa_supplicant-%{version}.tar.gz
Source1:	build.config
Source3:	%{name}.service
Source4:	%{name}.sysconfig
Source6:	%{name}.logrotate

# should be safe to just bump MAX_WEP_KEY_LEN to 32
# http://lists.shmoo.com/pipermail/hostap/2005-October/011787.html
Patch2:		wpa_supplicant-0.6.3-WEP232.patch
Patch5:		wpa_supplicant-1.0-mdv-dbus-service-file-args.patch
# quiet an annoying and frequent syslog message
Patch8:		wpa_supplicant-2.4-quiet-scan-results-message.patch
# works around busted drivers by increasing association timeout
Patch10:	wpa_supplicant-assoc-timeout.patch

# Fix for KRACKs major security issue
Patch20:	rebased-v2.6-0001-hostapd-Avoid-key-reinstallation-in-FT-handshake.patch
Patch21:	rebased-v2.6-0002-Prevent-reinstallation-of-an-already-in-use-group-ke.patch
Patch22:	rebased-v2.6-0003-Extend-protection-of-GTK-IGTK-reinstallation-of-WNM-.patch
Patch23:	rebased-v2.6-0004-Prevent-installation-of-an-all-zero-TK.patch
Patch24:	rebased-v2.6-0005-Fix-PTK-rekeying-to-generate-a-new-ANonce.patch
Patch25:	rebased-v2.6-0006-TDLS-Reject-TPK-TK-reconfiguration.patch
Patch26:	rebased-v2.6-0007-WNM-Ignore-WNM-Sleep-Mode-Response-without-pending-r.patch
Patch27:	rebased-v2.6-0008-FT-Do-not-allow-multiple-Reassociation-Response-fram.patch

BuildRequires:	doxygen
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(gnutls) >= 3.0
BuildRequires:	pkgconfig(libgcrypt)
BuildRequires:	pkgconfig(libnl-3.0)
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	pkgconfig(QtCore)
Requires(post,postun,preun):	rpm-helper
# http://ndiswrapper.sourceforge.net/wiki/index.php/WPA

%description
wpa_supplicant is a WPA Supplicant for Linux, BSD and Windows with
support for WPA and WPA2 (IEEE 802.11i / RSN). Supplicant is the IEEE
802.1X/WPA component that is used in the client stations. It
implements key negotiation with a WPA Authenticator and it controls
the roaming and IEEE 802.11 authentication/association of the wlan
driver.

wpa_supplicant is designed to be a "daemon" program that runs in the
background and acts as the backend component controlling the wireless
connection. wpa_supplicant supports separate frontend programs and an
example text-based frontend, wpa_cli, is included with wpa_supplicant.

Supported WPA/IEEE 802.11i features:
    * WPA-PSK ("WPA-Personal")
    * WPA with EAP (e.g., with RADIUS authentication server)
      ("WPA-Enterprise")
    * key management for CCMP, TKIP, WEP104, WEP40
    * WPA and full IEEE 802.11i/RSN/WPA2
    * RSN: PMKSA caching, pre-authentication

See the project web site or the eap_testing.txt file for a complete
list of supported EAP methods (IEEE 802.1X Supplicant), supported
drivers and interoperability testing.

%files
%doc wpa_supplicant/ChangeLog wpa_supplicant/README wpa_supplicant/eap_testing.txt wpa_supplicant/todo.txt
%doc wpa_supplicant/README-WPS
%doc wpa_supplicant/examples/*.conf
%attr(0600,root,daemon) %config(noreplace) %{_sysconfdir}/wpa_supplicant.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_systemunitdir}/%{name}.service
%{_sbindir}/wpa_cli
%{_sbindir}/wpa_passphrase
%{_sbindir}/wpa_supplicant
%{_sbindir}/eapol_test
%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
%{_datadir}/dbus-1/system-services/fi.epitest.hostap.WPASupplicant.service
%{_datadir}/dbus-1/system-services/fi.w1.wpa_supplicant1.service
%{_mandir}/man8/*
%{_mandir}/man5/*

%post
%systemd_post wpa_supplicant.service

%preun
%systemd_preun wpa_supplicant.service

%postun
%systemd_postun wpa_supplicant.service

#----------------------------------------------------------------------------

%package gui
Summary:	Graphical tool for wpa_supplicant
Group:		System/Configuration/Networking

%description gui
wpa_gui is a QT frontend for wpa_supplicant.
wpa_supplicant is a WPA Supplicant for Linux, BSD and Windows with
support for WPA and WPA2 (IEEE 802.11i / RSN).

%files gui
%{_bindir}/wpa_gui

#----------------------------------------------------------------------------

%prep
%setup -q
%apply_patches

pushd wpa_supplicant
# (blino) comment all "network = { }" blocks
perl -pi -e '$_ = "# $_" if /^\s*network\s*=\s*{/ .. /^\s*}/' wpa_supplicant.conf
cp %{SOURCE1} .config
popd

%build
%setup_compile_flags
# Fix bug #63030: dereferencing type-punned pointer will break strict-aliasing rules [-Werror=strict-aliasing]
export CFLAGS+=" -fno-strict-aliasing -Wno-error=deprecated-declarations"
export CXXFLAGS+=" -fno-strict-aliasing" FFLAGS+=" -fno-strict-aliasing"
export BINDIR=%{_sbindir}
export LIBDIR=%{_libdir}


pushd wpa_supplicant
%make
%make eapol_test
pushd wpa_gui-qt4
 %qmake_qt4
 %make
popd
popd

%install
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_sysconfdir}/dbus-1/system.d/
mkdir -p %{buildroot}%{_datadir}/dbus-1/system-services/

install -m644 %{SOURCE3} -D %{buildroot}%{_systemunitdir}/%{name}.service
install -m644 %{SOURCE4} -D %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -m644 %{SOURCE6} -D %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

pushd wpa_supplicant

# binaries
install -d %{buildroot}%{_sbindir}
install -m 755 wpa_supplicant %{buildroot}/%{_sbindir}
install -m 755 wpa_cli %{buildroot}/%{_sbindir}
install -m 755 wpa_passphrase %{buildroot}/%{_sbindir}
install -m 755 eapol_test %{buildroot}%{_sbindir}

# gui
install -d %{buildroot}%{_bindir}
install -m 755 wpa_gui-qt4/wpa_gui %{buildroot}%{_bindir}

# config
install -d -m 755 %{buildroot}%{_sysconfdir}
install -m 600 wpa_supplicant.conf %{buildroot}%{_sysconfdir}/wpa_supplicant.conf

# dbus
install -d %{buildroot}%{_sysconfdir}/dbus-1/system.d
install -d %{buildroot}%{_datadir}/dbus-1/system-services
install -m 644 dbus/dbus-wpa_supplicant.conf \
    %{buildroot}%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
install -m 644 dbus/fi.epitest.hostap.WPASupplicant.service \
    %{buildroot}%{_datadir}/dbus-1/system-services
install -m 0644 dbus/fi.w1.wpa_supplicant1.service \
     %{buildroot}%{_datadir}/dbus-1/system-services

# man pages
install -d -m 755 %{buildroot}%{_mandir}/man{5,8}
install -m 644 doc/docbook/*.8 %{buildroot}%{_mandir}/man8
install -m 644 doc/docbook/*.5 %{buildroot}%{_mandir}/man5

popd


%changelog

* Tue Oct 17 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.6-6
- (527d112) Fix KRACKs major security issue

* Sat Feb 04 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.6-5
- (4d1f85b) MassBuild#1230: Increase release tag

* Sat Dec 24 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 2.6-4
- (c47c7bd) Enable IBSS_RSN and BGSCAN_SIMPLE
- (c47c7bd) Similar to what is done in ArchLinux, Ubuntu, Fedora and OpenSUSE.

* Sat Dec 24 2016 Evgenii Shatokhin <eugene.shatokhin@rosalab.ru> 2.6-3
- (0d7a7c6) Make the build config a separate file rather than a patch to defconfig
- (0d7a7c6) It is easier to maintain it this way, experiment with options, etc.
- (Evgenii Shatokhin: 5f936a0) Updated to version 2.6

* Fri Oct 14 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.4-3
- (934c822) MassBuild#1169: Increase release tag

* Mon Jul 27 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 2.4-2
- (afb4d41) Fixed wpa_supplicant-2.4-rosa-defconfig.patch for version 2.4
- (Eugene Shatokhin: f4690ea) Several fixes based on the specs and configs from Fedora
- (Eugene Shatokhin: f4690ea) * Fixed the build config: enabled support for AP, logging to file, some
- (Eugene Shatokhin: f4690ea) other things.
- (Eugene Shatokhin: f4690ea) * Removed the excessive command-line parameters in the service file.

* Tue Jul 21 2015 Eugene Shatokhin <eugene.shatokhin@rosalab.ru> 2.4-1
- (c70c6e5) Updated to version 2.4

* Mon Apr 27 2015 kuzma kazygashev <kuzma.kazygashev@rosalab.ru> 2.2-5
- (b42b223) Increase release tag.

* Mon Apr 27 2015 kuzma kazygashev <kuzma.kazygashev@rosalab.ru> 2.2-4
- (b14a399) Security fix for CVE-2015-1863.
- (Alexander Lakhin: 08c9191) MassBuild#656: Increase release tag

* Thu Feb 05 2015 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.2-3
- (4130541) Drop unused patches and fix post scripts

* Wed Jul 09 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.2-2
- (fb44045) Minor cleanups

* Wed Jul 09 2014 Tigro <ashejn@gmail.com> 2.2-1
- (547dc08) update to 2.2

* Fri Jun 27 2014 Alex Burmashev <alex.burmashev@rosalab.ru> 1.1-4
- (6bd5758) MassBuild#440: Increase release tag

* Sun Aug 18 2013 akdengi <kazancas@mandriva.ru> 1.1-3
- (3502ff1) s/con/conf/
- (akdengi: 19b26d4) fix tmpfilesdir define
- (akdengi: 6535042) fix source numbering
- (akdengi: 888f9d1) up release

* Sun Aug 18 2013 akdengi <kazancas@mandriva.ru> 1.1-2
- (2167f62) some spec fix
- (akdengi: 56c8939) move tmpfiles to tmpfiles.d dir and fix systemd call

* Tue Dec 04 2012 Alexander Khryukin <alexander@mezon.ru> 1.1-1
- (573d6bd) version update 1.1

* Wed Sep 05 2012 akdengi <kazancas@mandriva.ru> 1.0-2
- (1e6f67d) LOG -use config file from Fedora
- (akdengi: 47f1ddc) LOG -drop madwifi as depricated
- (akdengi: 919a0ea) LOG -add libnl3 patch and fix spec for use qt4 gui instead standrat gui.

* Wed Sep 05 2012 akdengi <kazancas@mandriva.ru> 1.0-1
- (62fbb37) fix patch
- (akdengi: 19b269d) add missing patch
- (akdengi: 85bc1d8) fix patches
- (akdengi: f09e5f3) drop patch9
- (akdengi: 640e8d3) add patch source
- (akdengi: b0449c9) LOG -add patch for wpagui.h build


